#ifndef SVC_FIXPOINT_H
#define SVC_FIXPOINT_H

const unsigned long LOMAX = 1000000000l;
const unsigned long HIMAX = LOMAX;

typedef struct
{
    long	  hi;
    unsigned long lo;
} TwoLongs;

class FixPoint
{
public:
		FixPoint ();
		FixPoint (long double);
                FixPoint (const FixPoint&);
		FixPoint (const char *pszValue);
		FixPoint (const TwoLongs&);
	       ~FixPoint ();

	FixPoint &operator =  (const FixPoint &);
        FixPoint &operator *= (const FixPoint &);
        FixPoint &operator /= (const FixPoint &);
	FixPoint &operator += (const FixPoint &);
	FixPoint &operator -= (const FixPoint &);
	FixPoint &operator - () {negative = !negative; return *this;}

const	FixPoint &Percent (unsigned int) const;
	int	operator <  (const FixPoint &b) const;
	int	operator >  (const FixPoint &b) const;
	int	operator == (const FixPoint &b) const;
	int	operator != (const FixPoint &b) const {return !operator == (b);}
	int	operator <= (const FixPoint &b) const {return !operator > (b);}
	int	operator >= (const FixPoint &b) const {return !operator < (b);}

	int	IsNegative () const {return negative;}
	int	IsZero () const {return ((0 == hi) && (0 == lo));}
        int     IsPositive () const {return !IsNegative ();}
	int	IsGreaterThan (const FixPoint&) const;
	int	IsLessThan (const FixPoint&) const;
	void	ToString (char *pszBuffer, size_t SizeofBuffer) const;
const   TwoLongs &ToTwoLongs ();
private:
	unsigned long	 hi;
	unsigned long	 lo;
	unsigned int	 negative : 1;
	unsigned int	 point : 3;	 // 0 - 7

	void	Sub (const FixPoint &);
	void	Add (const FixPoint &);
};

const FixPoint &operator + (const FixPoint &, const FixPoint &);
const FixPoint &operator - (const FixPoint &, const FixPoint &);
const FixPoint &operator * (const FixPoint &, const FixPoint &);
const FixPoint &operator / (const FixPoint &, const FixPoint &);

#endif
